pub struct ZipEntryLocation {
pub file_name: String,
pub local_header_offset: u64,
pub compressed_size: u64,
pub uncompressed_size: u64,
pub extra_field_len: u64,
}Expand description
Location index of a file entry inside a ZIP archive.
Fields
file_name: Stringlocal_header_offset: u64compressed_size: u64uncompressed_size: u64extra_field_len: u64Implementations
Sourceimpl ZipEntryLocation
impl ZipEntryLocation
Sourcepub fn to_http_range_header(&self) -> (String, String)
pub fn to_http_range_header(&self) -> (String, String)
Generate HTTP Range header for fetching this entry over HTTP.